@@ -3,7 +3,6 @@ __all__ = ['to_itk_image', 'to_point_set', 'to_geometry']
 import itk
 import numpy as np
 
-
 def is_arraylike(arr):
     return hasattr(arr, 'shape') and \
         hasattr(arr, 'dtype') and \
@@ -135,6 +134,8 @@ def _numpy_array_to_point_set(point_set_like):
     point_values = np.asarray(point_set_like).astype(np.float32)
     if len(
             point_values.shape) > 1 and point_values.shape[1] == 2 or point_values.shape[1] == 3:
+        if not point_values.flags['CONTIGUOUS']:
+            point_values = np.ascontiguousarray(point_values)
         if point_values.shape[1] == 2:
             point_values = np.hstack(
                 (point_values, -5.0e-6 * np.ones((point_values.shape[0], 1)))).astype(np.float32)
@@ -160,6 +161,10 @@ def _numpy_array_to_point_set(point_set_like):
         return None
 
 def to_itk_image(image_like):
+
+    if isinstance(image_like, itk.Image):
+        return image_like
+
     if is_arraylike(image_like):
         array = np.asarray(image_like)
         case_use_view = array.flags['OWNDATA']
@@ -198,6 +203,8 @@ def to_itk_image(image_like):
             array = imglyb.to_numpy(image_like)
             image_from_array = itk.image_view_from_array(array)
             return image_from_array
+    elif isinstance(image_like, itk.ProcessObject):
+        return itk.output(image_like)
 
     return None
 
